---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: true
---

In the Amman Valley Maker Space, we used Info Screens with the Agenda and recent projects.
The events were aggregated from different sources: Discourse and Outlook Calendar.
With this, we informed the community about events that are going to happen using the Open Web Calendar Agenda View.
Events that were in the past were represented by a series of pictures.

![]({{link.img}}/showcase/infoscreen.jpg)

Used:

- Raspberry Pi
- A vertical screen
- Relais to the screen on and off
- Different Calendar Sources

You can view the [source code][infoscreen].

[infoscreen]: https://github.com/AmmanVMS/infoscreen
